"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertRunnerOption = exports.handleFilesOption = void 0;
const immutable_1 = require("immutable");
const cli_options_1 = require("../cli-options");
const types_1 = require("../../types");
const zod_1 = require("zod");
function handleFilesOption(incoming) {
    const namespaces = {
        core: {
            globs: [],
            objs: []
        }
    };
    const processed = (0, cli_options_1.makeFilesArg)(incoming.get("files"));
    if (processed.globs.length) {
        namespaces.core.globs = processed.globs;
    }
    if (processed.objs.length) {
        namespaces.core.objs = processed.objs;
    }
    const runners = convertRunnerOption(incoming);
    return [incoming.set("files", (0, immutable_1.fromJS)(Object.assign(Object.assign({}, namespaces), runners))), []];
}
exports.handleFilesOption = handleFilesOption;
function convertRunnerOption(incoming) {
    const runners = incoming.has("runners");
    if (!runners)
        return null;
    const parser = zod_1.z.array(types_1.runnerOption);
    const incomingOpt = incoming.get("runners").toJS();
    const runnerData = parser.parse(incomingOpt);
    const output = {};
    runnerData.forEach((runner, index) => {
        if (runner.at !== "runtime")
            return;
        const next = {
            index,
            globs: [],
            objs: []
        };
        for (let whenElement of runner.when) {
            if ("files" in whenElement) {
                whenElement.files.forEach(fileOption => {
                    next.globs.push(fileOption);
                });
                output["__unstable_runner_" + index] = next;
            }
            else {
                throw new Error("unreachable - only when.files supported currently");
            }
        }
    });
    return output;
}
exports.convertRunnerOption = convertRunnerOption;
//# sourceMappingURL=handleFilesOption.js.map