"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toReloadEvent = exports.toChangeEvent = exports.toRunnerNotification = exports.toSideEffect = exports.toRunnerOption = exports.runnerOption = exports.runtimeRunnerOption = exports.triggerSchema = exports.startupRunnerOption = void 0;
const zod_1 = require("zod");
const runnerParser = zod_1.z.union([
    zod_1.z.object({
        sh: zod_1.z.string()
    }),
    zod_1.z.object({
        bs: zod_1.z.literal("reload")
    }),
    zod_1.z.object({
        bs: zod_1.z.literal("inject"),
        files: zod_1.z.array(zod_1.z.string())
    }),
    zod_1.z.object({
        bs: zod_1.z.literal("inject-html"),
        selectors: zod_1.z.array(zod_1.z.string()).default([])
    }),
    zod_1.z.object({
        npm: zod_1.z.array(zod_1.z.string()),
        parallel: zod_1.z.boolean().optional()
    })
]);
exports.startupRunnerOption = zod_1.z.object({
    at: zod_1.z.literal("startup"),
    run: zod_1.z.array(runnerParser)
});
exports.triggerSchema = zod_1.z.union([
    zod_1.z.object({ files: zod_1.z.array(zod_1.z.string()) }),
    zod_1.z.object({ bs: zod_1.z.literal("started") })
]);
exports.runtimeRunnerOption = zod_1.z.object({
    at: zod_1.z.literal("runtime"),
    when: zod_1.z.array(exports.triggerSchema),
    run: zod_1.z.array(runnerParser)
});
exports.runnerOption = zod_1.z.discriminatedUnion("at", [exports.startupRunnerOption, exports.runtimeRunnerOption]);
function toRunnerOption(input) {
    const parsed = exports.runnerOption.safeParse(input);
    // todo: give good errors on format mistakes here
    return parsed.success ? parsed.data : null;
}
exports.toRunnerOption = toRunnerOption;
const sideEffectParser = zod_1.z.discriminatedUnion("type", [
    zod_1.z.object({ type: zod_1.z.literal("reload"), files: zod_1.z.array(zod_1.z.any()) }),
    zod_1.z.object({ type: zod_1.z.literal("inject"), files: zod_1.z.array(zod_1.z.any()) }),
    zod_1.z.object({ type: zod_1.z.literal("inject-html"), selectors: zod_1.z.array(zod_1.z.string()) })
]);
function toSideEffect(sideEffect) {
    return sideEffectParser.parse(sideEffect);
}
exports.toSideEffect = toSideEffect;
const notificationParser = zod_1.z.discriminatedUnion("status", [
    zod_1.z.object({
        runner: runnerParser,
        status: zod_1.z.literal("start"),
        effects: zod_1.z.array(sideEffectParser)
    }),
    zod_1.z.object({ runner: runnerParser, status: zod_1.z.literal("end"), effects: zod_1.z.array(sideEffectParser) })
]);
function toRunnerNotification(input) {
    return notificationParser.parse(input);
}
exports.toRunnerNotification = toRunnerNotification;
///
const fileChangedEventParser = zod_1.z.object({
    event: zod_1.z.string(),
    path: zod_1.z.string(),
    log: zod_1.z.boolean().optional(),
    namespace: zod_1.z.string(),
    index: zod_1.z.number().optional()
});
function toChangeEvent(evt) {
    return fileChangedEventParser.parse(evt);
}
exports.toChangeEvent = toChangeEvent;
/// Browser Reload Event
const browserReloadEvent = zod_1.z.object({
    files: zod_1.z.array(zod_1.z.union([zod_1.z.string(), fileChangedEventParser]))
});
function toReloadEvent(reload) {
    browserReloadEvent.parse(reload);
    return reload;
}
exports.toReloadEvent = toReloadEvent;
/// Inject File info
const injectFileInfo = zod_1.z.object({
    ext: zod_1.z.string(),
    path: zod_1.z.string(),
    basename: zod_1.z.string(),
    event: zod_1.z.unknown(),
    type: zod_1.z.enum(["inject", "reload"]),
    url: zod_1.z.string().optional(),
    log: zod_1.z.unknown() // You may want to replace this with a more specific type
});
//# sourceMappingURL=types.js.map